@@ -6,7 +6,7 @@
 
 #include "../src/map-quick/osmelementinformationmodel.h"
 
-#include <osm/xmlparser.h>
+#include <osm/io.h>
 
 #include <QAbstractItemModelTester>
 #include <QDir>
@@ -16,6 +16,9 @@
 #include <QJsonObject>
 #include <QProcess>
 #include <QTest>
+#include <QtPlugin>
+
+Q_IMPORT_PLUGIN(OSM_XmlIOPlugin)
 
 using namespace KOSMIndoorMap;
 
@@ -59,8 +62,8 @@ private Q_SLOTS:
         QVERIFY(inFile.open(QFile::ReadOnly));
 
         OSM::DataSet dataSet;
-        OSM::XmlParser p(&dataSet);
-        p.parse(&inFile);
+        auto p = OSM::IO::readerForFileName(osmFile, &dataSet);
+        p->read(&inFile);
         QCOMPARE(dataSet.nodes.size(), 1);
 
         OSMElementInformationModel model;
