@@ -12,6 +12,9 @@
 #include <QMetaEnum>
 #include <QProcess>
 #include <QTest>
+#include <QtPlugin>
+
+Q_IMPORT_PLUGIN(OSM_XmlIOPlugin)
 
 using namespace KOSMIndoorMap;
 
