@@ -6,6 +6,7 @@
 
 #include "kosmindoormap-kpublictransport-integration.h"
 #include "locationqueryoverlayproxymodel.h"
+#include "realtimeequipmentmodel.h"
 
 #include <QQmlEngine>
 
@@ -15,4 +16,5 @@ void KOSMIndoorMapQuickPlugin::registerTypes(const char *uri)
 {
     Q_UNUSED(uri);
     qmlRegisterType<LocationQueryOverlayProxyModel>("org.kde.kosmindoormap.kpublictransport", 1, 0, "LocationQueryOverlayProxyModel");
+    qmlRegisterType<RealtimeEquipmentModel>("org.kde.kosmindoormap.kpublictransport", 1, 0, "RealtimeEquipmentModel");
 }
