@@ -49,8 +49,11 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "chocolate", kli18nc("OSM::amenity/shop", "Chocolate") },
     { "cinema", kli18nc("OSM::amenity/shop", "Cinema") },
     { "citywalls", kli18nc("OSM::historic", "Citywall") },
+    { "class", kli18nc("OSM::room", "Classroom") },
+    { "classroom", kli18nc("OSM::room", "Classroom") },
     { "clothes", kli18nc("OSM::amenity/shop", "Clothes") },
     { "coffee", kli18nc("OSM::amenity/shop", "Coffee") },
+    { "community_centre", kli18nc("OSM::amenity", "Community Center") },
     { "computer", kli18nc("OSM::amenity/shop", "Computer") },
     { "confectionery", kli18nc("OSM::amenity/shop", "Confectionery") },
     { "convenience", kli18nc("OSM::amenity/shop", "Convenience Store") },
@@ -64,6 +67,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "drinking_water", kli18nc("OSM::amenity/shop", "Drinking Water") },
     { "dry_cleaning", kli18nc("OSM::amenity/shop", "Dry Cleaning") },
     { "electronics", kli18nc("OSM::amenity/shop", "Electronics") },
+    { "events_venue", kli18nc("OSM::amenity", "Events Venue") },
     { "fashion", kli18nc("OSM::amenity/shop", "Fashion") },
     { "fast_food", kli18nc("OSM::amenity/shop", "Fast Food") },
     { "ferry_terminal", kli18nc("OSM::amenity/shop", "Ferry Terminal") },
@@ -90,7 +94,10 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "internet_cafe", kli18nc("OSM::amenity/shop", "Internet Cafe") },
     { "jewelry", kli18nc("OSM::amenity/shop", "Jewelry") },
     { "kiosk", kli18nc("OSM::amenity/shop", "Kiosk") },
+    { "kitchen", kli18nc("OSM::room", "Kitchen") },
     { "laundry", kli18nc("OSM::amenity/shop", "Laundry") },
+    { "lecture", kli18nc("OSM::room", "Lecture Hall") },
+    { "lecture_hall", kli18nc("OSM::room", "Lecture Hall") },
     { "library", kli18nc("OSM::amenity/shop", "Library") },
     { "lockers", kli18nc("OSM::amenity/shop", "Locker") },
     { "locksmith", kli18nc("OSM::amenity/shop", "Locksmith") },
@@ -129,7 +136,9 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "post_office", kli18nc("OSM::amenity/shop", "Post Office") },
     { "pub", kli18nc("OSM::amenity/shop", "Pub") },
     { "public_transport_tickets", kli18nc("OSM::amenity/shop", "Public Transport Tickets") },
+    { "railway_station", kli18nc("OSM::building", "Train Station") },
     { "recycling", kli18nc("OSM::amenity/shop", "Recycling") },
+    { "research_institute", kli18nc("OSM::amenity", "Research Institute") },
     { "restaurant", kli18nc("OSM::amenity/shop", "Restaurant") },
     { "school", kli18nc("OSM::amenity/shop", "School") },
     { "scooter_rental", kli18nc("OSM::amenity/shop", "Kick Scooter Rental") },
@@ -139,6 +148,8 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "social_facility", kli18nc("OSM::amenity/shop", "Social Facility") },
     { "souveniers", kli18nc("OSM::amenity/shop", "Souvenirs") },
     { "sports", kli18nc("OSM::amenity/shop", "Sports") },
+    { "sports_centre", kli18nc("OSM::amenity", "Sports Center") },
+    { "sports_hall", kli18nc("OSM::amenity", "Sports Hall") },
     { "stationery", kli18nc("OSM::amenity/shop", "Stationery") },
     { "supermarket", kli18nc("OSM::amenity/shop", "Supermarket") },
     { "tailor", kli18nc("OSM::amenity/shop", "Tailor") },
@@ -151,6 +162,7 @@ static constexpr const ValueMapEntry amenity_map[] = {
     { "toilets", kli18nc("OSM::amenity/shop", "Toilets") },
     { "townhall", kli18nc("OSM::amenity/shop", "Town Hall") },
     { "toys", kli18nc("OSM::amenity/shop", "Toys") },
+    { "train_station", kli18nc("OSM::building", "Train Station") },
     { "travel_agency", kli18nc("OSM::amenity/shop", "Travel Agency") },
     { "travel_agent", kli18nc("OSM::amenity/shop", "Travel Agency") },
     { "university", kli18nc("OSM::amenity/shop", "University") },
@@ -355,4 +367,32 @@ static constexpr const ValueMapEntry available_vehicles_map[] = {
     { "mx:realtime_available:car", kli18ncp("available rental vehicles", "%1 car", "%1 cars") },
 };
 
+// gender neutral/gender segregated facilities
+struct {
+    const char *keyName;
+    const KLazyLocalizedString label;
+
+    constexpr inline OSMElementInformationModel::Key key() const { return OSMElementInformationModel::Gender; }
+    constexpr inline OSMElementInformationModel::KeyCategory category() const { return OSMElementInformationModel::UnresolvedCategory; }
+} static constexpr const gender_type_map[] = {
+    { "female", kli18nc("OSM::gender_segregation", "female") },
+    { "male", kli18nc("OSM::gender_segregation", "male") },
+    { "unisex", kli18nc("OSM::gender_segregation", "unisex") },
+};
+static_assert(isSortedLookupTable(gender_type_map), "gender type map is not sorted!");
+
+// tactile writing variants
+struct {
+    const char *keyName;
+    const KLazyLocalizedString label;
+
+    constexpr inline OSMElementInformationModel::Key key() const { return OSMElementInformationModel::TactileWriting; }
+    constexpr inline OSMElementInformationModel::KeyCategory category() const { return OSMElementInformationModel::Accessibility; }
+} static constexpr const tactile_writing_map[] = {
+    { "tactile_writing:braille", kli18nc("tactile writing", "braille") },
+    { "tactile_writing:embossed_printed_letters", kli18nc("tactile writing", "embossed printed letters") },
+    { "tactile_writing:engraved_printed_letters", kli18nc("tactile writing", "engraved printed letters") },
+};
+static_assert(isSortedLookupTable(tactile_writing_map), "tactile writing type map is not sorted!");
+
 }
