@@ -15,8 +15,7 @@
 #include <osm/datasetmergebuffer.h>
 #include <osm/element.h>
 #include <osm/o5mparser.h>
-#include <osm/osmpbfparser.h>
-#include <osm/xmlparser.h>
+#include <osm/io.h>
 
 #include <QDateTime>
 #include <QElapsedTimer>
@@ -79,17 +78,12 @@ void MapLoader::loadFromFile(const QString &fileName)
     const auto data = f.map(0, f.size());
 
     OSM::DataSet ds;
-    if (fileName.endsWith(QLatin1String(".osm.pbf"))) {
-        OSM::OsmPbfParser p(&ds);
-        p.parse(data, f.size());
-    } else if (fileName.endsWith(QLatin1String(".osm"))) {
-        qDebug() << fileName << f.pos() <<f.size();
-        OSM::XmlParser p(&ds);
-        p.parse(&f);
-    } else {
-        OSM::O5mParser p(&ds);
-        p.parse(data, f.size());
+    auto reader = OSM::IO::readerForFileName(fileName, &ds);
+    if (!reader) {
+        qCWarning(Log) << "no file reader for" << fileName;
+        return;
     }
+    reader->read(data, f.size());
     d->m_data = MapData();
     d->m_data.setDataSet(std::move(ds));
     qCDebug(Log) << "o5m loading took" << loadTime.elapsed() << "ms";
@@ -161,7 +155,7 @@ void MapLoader::loadTiles()
             break;
         }
         const auto data = f.map(0, f.size());
-        p.parse(data, f.size());
+        p.read(data, f.size());
         d->m_marbleMerger.merge(&d->m_mergeBuffer);
 
         d->m_tileBbox = OSM::unite(d->m_tileBbox, tile.boundingBox());
